@@ -602,13 +602,14 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle'):
             pickle.dump(GD_SN, fp)
 
     #gradient ascent algorithm for the SNe that didn't pass this stage
-    SN_toReassociate = np.concatenate([np.array(noHosts), np.array(GD_SN), np.array(list(lost))])
-    SN_toReassociate = np.array(SN_toReassociate)
+    #SN_toReassociate = np.concatenate([np.array(noHosts), np.array(GD_SN), np.array(list(lost))])
+    SN_toReassociate = np.concatenate([np.array(noHosts), np.array(list(lost))])
+    #SN_toReassociate = np.array(SN_toReassociate)
 
     if len(SN_toReassociate) > 0:
         if verbose:
             print("%i transients with no host found with DLR, %i transients with bad host data with DLR." %(len(noHosts), len(GD_SN)))
-            print("Running gradient ascent for %i remaining transients..."%len(SN_toReassociate))
+            print("Running gradient ascent for %i remaining transients in the hostless sample..."%len(SN_toReassociate))
             print("See GradientAscent.txt for more information.")
 
         fn_GD= path+'/GradientAscent.txt'
